@@ -14,14 +14,30 @@ icon_ico_source = f'{proj_path}/icon.ico'
 c = rich.console.Console()
 print = c.print
 portable = 'portable' in sys.argv
-yes_or_no = Sel(
-    items = [
+yes_no = Sel(
+    items=[
         'yes',
         'no',
+        'exit',
     ],
-    styles = [
+    styles=[
         'green',
-        'red'
+        'red',
+        'bright_black',
+    ]
+)
+alw_yes_no = Sel(
+    items=[
+        'yes',
+        'always yes',
+        'no',
+        'exit',
+    ],
+    styles=[
+        'green',
+        'green',
+        'red',
+        'bright_black',
     ]
 )
 
@@ -37,7 +53,8 @@ def linux():
     home = Path.home()
     share = f'{home}/.local/share'
 
-    dotdesktop_path = Path(f'{home}/.local/share/applications/PrettyGit.desktop')
+    dotdesktop_path = Path(
+        f'{home}/.local/share/applications/PrettyGit.desktop')
     if dotdesktop_path.exists():
         return
     dotdesktop_path.parent.mkdir(
@@ -49,7 +66,7 @@ def linux():
         'w',
     ) as dotdesktop:
         dotdesktop.write(
-'''\
+            '''\
 [Desktop Entry]
 Comment=very simple and user friendly interface for git
 Type=Application
@@ -73,8 +90,8 @@ Exec=/bin/python -m prettygit
         f'{share}/icons/PrettyGit.svg',
     )
 
-    print(
-f'''
+    act = yes_no.choose(
+        f'''
 [green]\
 Created file [deep_sky_blue1]{dotdesktop_path}
 
@@ -89,14 +106,19 @@ Then you will be able to run this script with [deep_sky_blue1]prettygit[/deep_sk
 Creating this shortcuts requires sudo\
 '''
     )
-    if yes_or_no.choose() == 'no':
-        return
+    match act:
+        case 'yes':
+            pass
+        case 'no':
+            return
+        case 'exit':
+            sys.exit()
     script = '''\
 #!/bin/bash
 python -m prettygit
 '''
     os.system(
-f'''
+        f'''
 echo "{script}" | sudo tee /bin/pg /bin/prettygit
 sudo chmod +x /bin/prettygit
 sudo chmod +x /bin/pg
@@ -127,8 +149,8 @@ def windows():
     )
 
     start_menu.parent.mkdir(
-        parents = True,
-        exist_ok = True,
+        parents=True,
+        exist_ok=True,
     )
 
     shortcut_creator_path = f'{proj_path}/shortcut_creator.vbs'
@@ -138,7 +160,7 @@ def windows():
         'w'
     ) as shortcut_creator:
         shortcut_creator.write(
-f'''\
+            f'''\
 set WshShell = WScript.CreateObject("WScript.Shell")
 set Shortcut = WshShell.CreateShortcut("{shortcut}")
 Shortcut.TargetPath = "{sys.executable}"
